sparky-info for Debian
---------------------

<This file describes information about the source package, see Debian policy
manual section 4.14. You WILL either need to modify or delete this file.>



 -- pavroo <pavroo@onet.eu>  Sat, 14 Feb 2026 13:35:13 +0100
